@@ -520,10 +520,9 @@ public class HandlerChainInvokerTest extends Assert {
         assertTrue(logicalHandlers[1].getInvokeOrderOfHandleMessage()
                    < logicalHandlers[2].getInvokeOrderOfHandleMessage());
         
-        //Close is invoked outside HandlerChainInvoker, eg, in SOAPHandlerInterceptor
-        assertEquals(0, logicalHandlers[0].getCloseCount());
-        assertEquals(0, logicalHandlers[1].getCloseCount());
-        assertEquals(0, logicalHandlers[2].getCloseCount());
+        assertEquals(1, logicalHandlers[0].getCloseCount());
+        assertEquals(1, logicalHandlers[1].getCloseCount());
+        assertEquals(1, logicalHandlers[2].getCloseCount());
         assertEquals(0, logicalHandlers[3].getCloseCount());
 
         assertEquals(0, logicalHandlers[0].getHandleFaultCount());
@@ -616,7 +615,8 @@ public class HandlerChainInvokerTest extends Assert {
         //boolean continueProcessing = true;
         try {
             invoker.invokeLogicalHandlers(false, lmc);
-            fail("did not get expected exception");
+            //don't fail.  TCK says this shouldn't be thrown.
+            //fail("did not get expected exception");
         } catch (ProtocolException e) {
             assertEquals("banzai", e.getMessage());
         }
